/*
 * @Copyright 2010, MechSoft 
 * MechSoft, Mechanical and Software Solutions 
 * 
 * All rights are reserved to MechSoft
 */
package org.defne.service;

import org.defne.utility.Assertions;

/**
 * Factory for {@link Message}
 * 
 * @author gurkanerdogdu
 * @version $Rev$ $Date$
 */
public final class MessageFactory
{
    /**
     * Private constructor.
     */
    private MessageFactory()
    {
        throw new UnsupportedOperationException();
    }
    
    /**
     * Returns an empty service bag.
     * @return a bag
     */
    public static Message newMessage()
    {
        return new Message();
    }
    
    /**
     * Returns an empty service bag.
     * @return a bag
     */
    public static Message newServiceBag(boolean returns)
    {
        if(returns) return newMessage();
        
        return null;
    }

    /**
     * Gets new service bag instance with given name.
     * 
     * @param serviceName service name
     * @return new service bag
     */
    public static Message newMessage(String serviceName)
    {
        Assertions.checkForNull(serviceName, "service name can not be null");
        return new Message(serviceName);
    }

    /**
     * Gets new service bag instance with given service name and method name.
     * 
     * @param serviceName service name
     * @param methodName method name of the service
     * @return new service bag
     */
    public static Message newMessage(String serviceName, String methodName)
    {
        Assertions.checkForNull(serviceName, "serviceName can not be null");
        Assertions.checkForNull(serviceName, "methodName can not be null");

        return new Message(serviceName, methodName);
    }

}
