/*
 * @Copyright 2010, MechSoft 
 * MechSoft, Mechanical and Software Solutions 
 * 
 * Licensed under the Apache License, Version 2.0 (the 
 * "License"); you may not use this file except in compliance 
 * with the License. You may obtain a copy of the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.defne.service.executor;

import org.defne.service.Message;
import org.defne.utility.exception.DefneException;

/**
 * Service executor local interface.
 * <p>
 * This is the EJB local interface marker. If the
 * service execution is called over using EJBs, executor
 * EJB must implement this interface.
 * </p>
 * 
 * @author gurkanerdogdu
 * @version $Rev$ $Date$
 */
public interface IServiceExecutor
{
    /**Key for getting the JNDI name of the 
     * EJB executor contained in EJB container.*/
    String SERVICE_EXECUTOR_JNDI_INIT_PARAMETER = "org.defne.service.executor.EXECUTOR_JNDI";

    /**
     * Execute the service within transaction.
     * 
     * @param inputBag input bag of the service
     * @return result of the service execution
     * @throws Exception for exception
     */
    public Message executeWithTransaction(Message inputBag) throws DefneException;

    /**
     * Execute the service without transaction.
     * 
     * @param inputBag input bag of the service
     * @return result of the service execution
     * @throws Exception for exception
     */
    public Message executeWithoutTransaction(Message inputBag) throws DefneException;

    /**
     * Execute the service with new transaction.
     * 
     * @param inputBag input bag of the service
     * @return result of the service execution
     * @throws Exception for exception
     */
    public Message executeWithNewTransaction(Message inputBag) throws DefneException;
}
