/*
 * @Copyright 2010, MechSoft 
 * MechSoft, Mechanical and Software Solutions 
 * 
 * Licensed under the Apache License, Version 2.0 (the 
 * "License"); you may not use this file except in compliance 
 * with the License. You may obtain a copy of the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.defne.service.executor;

import org.defne.service.Message;
import org.defne.service.MessageParam;
import org.defne.utility.exception.DefneException;

/**
 * Contract for proxying the service requests.
 * <p>
 * Implementation of this interface, propogate the
 * service execution requests to the actual service executor.
 * </p>
 * @version $Rev$ $Date$
 *
 */
public interface IServiceExecutorProxy
{   
    /**
     * Executes the service that is specificed in the
     * input parameter with {@link MessageParam#SERVICE_NAME_KEY}
     * and {@link MessageParam#SERVICE_METHOD_NAME_KEY}.
     * @param inBag service input parameters container
     * @return the service execution result
     * @throws DefneException exception that containes the cause
     */
    public Message execute(Message inBag) throws DefneException;
    
    /**
     * Clear the proxy execution context.
     */
    public void clear(Object clearObject);
}
