/*
 * @Copyright 2010, MechSoft 
 * MechSoft, Mechanical and Software Solutions 
 * 
 * Licensed under the Apache License, Version 2.0 (the 
 * "License"); you may not use this file except in compliance 
 * with the License. You may obtain a copy of the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.defne.service.scanner;

import java.net.URL;
import java.util.HashSet;
import java.util.Map;
import java.util.Set;

import org.defne.service.annotation.Service;
import org.defne.utility.reflection.ReflectionUtils;
import org.scannotation.AnnotationDB;
import org.scannotation.ClasspathUrlFinder;

/**
 * Scan the classpath for the services.
 * @author gurkanerdogdu
 * @version $Rev: 51 $ $Date: 2010-06-14 15:05:14 +0300 (Mon, 14 Jun 2010) $
 */
public class DefaultScanner extends AbstractScanner
{
    
    /**
     * {@inheritDoc}
     */
    @Override
    public Set<Class<?>> scan(ClassLoader classLoader) throws Exception
    {
        URL[] urls = ClasspathUrlFinder.findResourceBases("META-INF/defne-service.xml", classLoader);
        AnnotationDB annotatDb = new AnnotationDB();
        annotatDb.scanArchives(urls);
        
        Set<Class<?>> returnClasses = new HashSet<Class<?>>();
        Map<String, Set<String>> classes = annotatDb.getClassIndex();
        Set<String> strClasses = classes.keySet();
        if(strClasses != null)
        {
            for(String strClass : strClasses)
            {
                Class<?> clazz = ReflectionUtils.getClassFromName(strClass);
                if(clazz.isAnnotationPresent(Service.class))
                {
                    returnClasses.add(clazz);
                }
            }
        }
        
        return returnClasses;
    }

}
