/*
 * @Copyright 2010, MechSoft 
 * MechSoft, Mechanical and Software Solutions 
 * 
 * Licensed under the Apache License, Version 2.0 (the 
 * "License"); you may not use this file except in compliance 
 * with the License. You may obtain a copy of the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.defne.service.scanner;

import java.io.IOException;
import java.io.InputStream;
import java.util.Properties;

import org.defne.utility.exception.DefneException;
import org.defne.utility.reflection.ReflectionUtils;

public class ScannerFactory
{
    private final Properties properties;
    
    private static final String SCANNER_KEY = "org.defne.service.scanner.IScanner";
    
    public ScannerFactory()
    {
        properties = new Properties();
        try
        {
            //Default properties
            properties.load(ReflectionUtils.getThreadClassLoader().getResourceAsStream("META-INF/defne-default-service.properties"));
            
            //Override properties
            InputStream is = ReflectionUtils.getThreadClassLoader().getResourceAsStream("META-INF/defne-service.properties");
            if(is != null)
            {
                properties.load(is);
            }
        }
        catch (IOException e)
        {
            throw new DefneException(e);
        }        
    }
    
    public IScanner getScanner()
    {
        Class<?> clazz = ReflectionUtils.getClassFromName(this.properties.getProperty(SCANNER_KEY));        
        Object instance = null;
        try
        {
            instance = clazz.newInstance();
            
            return IScanner.class.cast(instance); 
        }
        catch (InstantiationException e)
        {
            throw new DefneException(e);
        }
        catch (IllegalAccessException e)
        {
            throw new DefneException(e);
        }
        
    }
}
