/*
 * @Copyright 2010, MechSoft 
 * MechSoft, Mechanical and Software Solutions 
 * 
 * Licensed under the Apache License, Version 2.0 (the 
 * "License"); you may not use this file except in compliance 
 * with the License. You may obtain a copy of the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.defne.service.scanner;

import javax.servlet.ServletContextEvent;
import javax.servlet.ServletContextListener;

import org.defne.service.annotation.ServiceScanner;
import org.defne.utility.factories.SingletonProvider;
import org.defne.utility.log.ILogger;
import org.defne.utility.log.LoggerProvider;
import org.defne.utility.reflection.ReflectionUtils;

public class ScannerListener implements ServletContextListener
{
    private static final ILogger logger = LoggerProvider.getLogProvider(ScannerListener.class);
    
    private ServiceScanner serviceScanner;
    
    @Override
    public void contextDestroyed(ServletContextEvent arg0)
    {
        if(this.serviceScanner != null)
        {
            ClassLoader classLoader = ReflectionUtils.getThreadClassLoader(); 
            this.serviceScanner.remove(classLoader);
        }
        
        //Remove all cache instances
        SingletonProvider.clearInstances(ReflectionUtils.getThreadClassLoader());
    }

    @Override
    public void contextInitialized(ServletContextEvent event)
    {
        ClassLoader classLoader = ReflectionUtils.getThreadClassLoader(); 
        serviceScanner = (ServiceScanner)SingletonProvider.getSingletonInstance(SingletonProvider.SERVICE_SCANNER_CLASS, classLoader);
        try
        {
            if(logger.isDebugEnabled())
            {
                logger.debug("Starting to scanning classpath for the context path : " + 
                        event.getServletContext().getContextPath());
            }
            
            serviceScanner.scan(classLoader);
        }
        catch (Exception e)
        {
            if(logger.isErrorEnabled())
            {
                logger.error("Error is occured while scanning classpath for the context path : " + 
                        event.getServletContext().getContextPath(), e);                
            }
            
            throw new RuntimeException(e);
        }
    }

}
